// A HighOrderComponent to host the logic we need in order to achieve permissions tracking for an element.
import { useRouter } from "next/router";
import React from "react";
import { Redirects } from "../interfaces/enums";
var elementWithPermissions = function (Component, state) {
    var Permissions = function () {
        var _a;
        // Login data added to props via redux-store (or use react context for example)
        if (!state.userData)
            return React.createElement(React.Fragment, null);
        if (!state.userData.permissions)
            return React.createElement(React.Fragment, null);
        var hasPermissions = !!state.userData && state.userData.permissions.length > 0;
        var isAdmin = ((_a = state.userData) === null || _a === void 0 ? void 0 : _a.permissions[0].permission) === "superAdmin";
        if (!hasPermissions || !isAdmin)
            return React.createElement(React.Fragment, null);
        // If user is logged in, return original component
        return React.createElement(Component, null);
    };
    return Permissions;
};
export var pageWithPermissions = function (Component, state) {
    var PagePermissions = function () {
        var _a, _b;
        var router = useRouter();
        var isWindowDefined = typeof window !== "undefined";
        // If user is not logged in, return an empty component and push to login page
        if (!state.userData && isWindowDefined) {
            router.push(Redirects.BAD_USER_DATA);
            return React.createElement(React.Fragment, null);
        }
        if (!((_a = state.userData) === null || _a === void 0 ? void 0 : _a.permissions))
            return React.createElement(React.Fragment, null);
        var hasPermissions = !!state.userData && state.userData.permissions.length > 0;
        var isAdmin = ((_b = state.userData) === null || _b === void 0 ? void 0 : _b.permissions[0].permission) === "superAdmin";
        if (!hasPermissions || !isAdmin) {
            if (typeof window !== undefined && router.isReady) {
                router.push(Redirects.NOT_FOUND);
            }
            return React.createElement(React.Fragment, null);
        }
        // If user is logged in, return original component
        return React.createElement(Component, null);
    };
    // Copy getInitial props so it will run as well
    if (Component.getInitialProps) {
        PagePermissions.getInitialProps = Component.getInitialProps;
    }
    return PagePermissions;
};
export default elementWithPermissions;
